translate.storage.versioncontrol.bzr

Package translate :: Package storage :: Package versioncontrol :: Module bzr |
[hide private]
[frames] | no frames]

# Module bzr

source code

Classes | [hide private]
| bzr Class to manage items under revision control of bzr.

Functions | [hide private]
is_available() check if bzr is installed | source code
get_version() return a tuple of (major, minor) for the installed bazaar client | source code

Variables | [hide private]
| __package__ = ``'``translate.storage.versioncontrol``'``

Imports: translate, GenericRevisionControlSystem, run_command